==> v8.3.zip: ru_twords_ru_tw/bible/other/purple.md <==
# пурпурный

## Определение:

Пурпурным называется такой цвет, который получается от смешения синего и красного красителей. У этого цвета множество оттенков: от багрового до фиолетового.

* В древности пурпурный (фиолетовый) цвет получался за счёт применения очень редкого и ценного красителя, использующегося для окраски одежды царей и высокопоставленных чиновников.
* Пурпурная краска была очень дорогой, на её изготовление уходило много времени, и поэтому одежда этого цвета считалась признаком роскоши, исключительности и царственности.
* Пурпурный цвет был одним из цветов занавесей в скинии и храме. Такого же цвета были ефоды (один из элементов одежды) священников.
* Пурпурную краску получали из определённого вида моллюсков. Для этого разными способами добивались, чтобы малюски выпускали необходимую краску. Это был дорогостоящий процесс.
* Римские воины одели Иисуса в пурпурную царскую мантию (устар. — багряницу) перед Его распятием. Так они насмехаясь над Ним за то, что Он признал Себя иудейским Царём.
* Одна из женщин, упомянутых в Библии, Лидия из города Филиппы, зарабатывала на жизнь торговлей пурпурной тканью (багряницей).

(Варианты перевода: [Как переводить имена](rc://*/ta/man/translate/translate-names))

(См. также [ефод](../kt/ephod.md), [Филиппы](../names/philippi.md), [царский](../other/royal.md), [скиния](../kt/tabernacle.md), [храм](../kt/temple.md))

## Ссылки на библейский текст:

* [2 Пар. 2:13-14](rc://*/tn/help/2ch/02/13)
* [Дан. 5:7](rc://*/tn/help/dan/05/07)
* [Дан. 5:29-31](rc://*/tn/help/dan/05/29)
* [Притч. 31:22-23](rc://*/tn/help/pro/31/22)

## Данные о слове:

* Номера Стронга: H710, H711, H713, G4209, G4210, G4211

==> v9.2.zip: ru_twords_ru_tw/bible/other/purple.md <==
# пурпурный

## Определение:

Пурпурным называется такой цвет, который получается от смешения синего и красного красителей. У этого цвета множество оттенков: от багрового до фиолетового.
* В древности пурпурный (фиолетовый) цвет получался за счёт применения очень редкого и ценного красителя, использующегося для окраски одежды царей и высокопоставленных чиновников.
* Пурпурная краска была очень дорогой, на её изготовление уходило много времени, и поэтому одежда этого цвета считалась признаком роскоши, исключительности и царственности.
* Пурпурный цвет был одним из цветов занавесей в скинии и храме. Такого же цвета были ефоды (один из элементов одежды) священников.
* Пурпурную краску получали из определённого вида моллюсков. Для этого разными способами добивались, чтобы малюски выпускали необходимую краску. Это был дорогостоящий процесс.
* Римские воины одели Иисуса в пурпурную царскую мантию (устар. — багряницу) перед Его распятием. Так они насмехаясь над Ним за то, что Он признал Себя иудейским Царём.
* Одна из женщин, упомянутых в Библии, Лидия из города Филиппы, зарабатывала на жизнь торговлей пурпурной тканью (багряницей).

(Варианты перевода: [Как переводить имена](rc://ru/ta/man/translate/translate-names))

(См. также [ефод](../kt/ephod.md), [Филиппы](../names/philippi.md), [царский](../other/royal.md), [скиния](../kt/tabernacle.md), [храм](../kt/temple.md))

## Ссылки на библейский текст:

* [2 Пар. 2:13-14](rc://ru/tn/help/2ch/02/13)
* [Дан. 5:7](rc://ru/tn/help/dan/05/07)
* [Дан. 5:29-31](rc://ru/tn/help/dan/05/29)
* [Притч. 31:22-23](rc://ru/tn/help/pro/31/22)

## Данные о слове:

* Номера Стронга: H710, H711, H713, G4209, G4210, G4211
